"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const ExtractTextPlugin = require("extract-text-webpack-plugin");
const common_1 = require("./common");
const outputs_1 = require("./outputs");
const plugins_1 = require("./plugins");
const rules_1 = require("./rules");
const isProduction = (process.argv.indexOf("-p") !== -1);
class WebpackConfigBuilder {
    constructor(entry, parallelBuild = true) {
        this.entry = entry;
        this.parallelBuild = parallelBuild;
        const entryKeys = Object.getOwnPropertyNames(entry);
        if (entryKeys.length === 0) {
            throw new Error("Entry should contain at least one key-value pair.");
        }
        this.defaultEntryName = entryKeys[0];
    }
    toUmdConfig(outputPath, ...plugins) {
        const defaultPluginsList = this.parallelBuild ? plugins_1.defaultPlugins : [];
        return {
            mode: isProduction ? "production" : "development",
            stats: { modules: false },
            entry: this.entry,
            resolve: common_1.getDefaultResolveSection(),
            output: outputs_1.asUmdLib(outputPath),
            module: {
                rules: rules_1.getDefaultClientRules(this.parallelBuild),
            },
            plugins: [...defaultPluginsList, ...plugins, new ExtractTextPlugin(this.defaultEntryName + ".css")],
        };
    }
    toServerConfig(outputPath, ...plugins) {
        const defaultPluginsList = this.parallelBuild ? plugins_1.defaultPlugins : [];
        return {
            mode: isProduction ? "production" : "development",
            stats: { modules: false },
            entry: this.entry,
            resolve: common_1.getDefaultResolveSection(),
            output: outputs_1.asServerLib(outputPath),
            target: "node",
            devtool: "source-map",
            module: {
                rules: rules_1.getDefaultServerRules(this.parallelBuild),
            },
            plugins: [...defaultPluginsList, ...plugins],
        };
    }
}
exports.WebpackConfigBuilder = WebpackConfigBuilder;
